@@ -14,10 +14,10 @@ const char testname[] = "Executable stack                         ";
 
 void doit( void )
 {
-	char buf[8192];
+	char buf[MAX_SHELLCODE_LEN];
 	fptr func;
 
-	copy_shellcode(buf, SHELLCODE_RETURN);
+	copy_shellcode(buf);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
