@@ -4,16 +4,17 @@
  * This file has been released under the GNU Public Licence version 2 or later
  */
 
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
-#define __USE_GNU
 #include <dlfcn.h>
 
-
+/* OpenBSD 3.5 doesn't define RTLD_DEFAULT */
+/* OpenBSD 3.6 does but it doesn't actually handle (segfaults on) RTLD_DEFAULT, sigh... */
 #ifdef __OpenBSD__
-#define RTLD_DEFAULT   ((void *) 0)
-#endif 
-
+#undef RTLD_DEFAULT
+#define RTLD_DEFAULT "libc.so"
+#endif
 
 int main( int argc, char *argv[] )
 {
@@ -22,11 +23,12 @@ int main( int argc, char *argv[] )
 	handle = dlopen( RTLD_DEFAULT, RTLD_LAZY );
 	if( handle != NULL ) {
 		void *sprintf;
-	       
+
+		dlerror(); /* clear any errors */
 		sprintf = dlsym( handle, "sprintf" );
 
 		if( dlerror() == NULL ) {
-			printf( "%0p\n", sprintf );
+			printf( "%p\n", sprintf );
 		}
 
 		dlclose( handle );
