@@ -3,11 +3,12 @@
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
  */
-#include "shellcode.h"
 
-char shbss[4096];
+#include "paxtest.h"
 
-char shdata[4096] = SHELLCODE_RETURN_ARRAY;
+char shbss[PAGE_SIZE_MAX] __pagealigned;
+
+char shdata[PAGE_SIZE_MAX] __pagealigned = { 'A' };
 
 /* A function which does nothing, it only exists so it can be referenced */
 int shlibtest( void )
